@@ -100,10 +100,10 @@ sub build_exe_file {
   
   my $quiet = $self->{quiet};
   
-  # Create workd dir
-  my $tmp_dir = "$build_dir/work/tmp";
-  mkpath $tmp_dir;
-
+  # Object directry
+  my $object_dir = "$build_dir/work/exe/object";
+  mkpath $object_dir;
+  
   # Build native packages
   my $builder_c_native = SPVM::Builder::CC->new(
     build_dir => $build_dir,
@@ -117,13 +117,12 @@ sub build_exe_file {
     my $native_dir = $native_module_file;
     $native_dir =~ s/\.spvm$//;
     $native_dir .= 'native';
-    my $input_dir = SPVM::Builder::Util::remove_package_part_from_file($native_module_file, $native_package_name);
+    my $src_dir = SPVM::Builder::Util::remove_package_part_from_file($native_module_file, $native_package_name);
     $builder_c_native->compile(
       $native_package_name,
       {
-        input_dir => $input_dir,
-        tmp_dir => "$build_dir/work/tmp",
-        output_dir => "$build_dir/work/tmp",
+        src_dir => $src_dir,
+        object_dir => $object_dir,
       }
     );
   }
@@ -141,26 +140,25 @@ sub build_exe_file {
     my $precompile_dir = $precompile_module_file;
     $precompile_dir =~ s/\.spvm$//;
     $precompile_dir .= 'precompile';
-    my $input_dir;
+    my $src_dir;
     if (-f $precompile_dir) {
-      $input_dir = SPVM::Builder::Util::remove_package_part_from_file($precompile_module_file, $precompile_package_name);
+      $src_dir = SPVM::Builder::Util::remove_package_part_from_file($precompile_module_file, $precompile_package_name);
     }
     else {
-      $input_dir = "$build_dir/work/tmp";
+      $src_dir = "$build_dir/work/exe/src";
       $builder_c_precompile->create_source_precompile(
         $precompile_package_name,
         [],
         {
-          tmp_dir => $input_dir,
+          src_dir => $src_dir,
         }
       );
     }
     $builder_c_precompile->compile(
       $precompile_package_name,
       {
-        input_dir => $input_dir,
-        tmp_dir => "$build_dir/work/tmp",
-        output_dir => "$build_dir/work/tmp",
+        src_dir => $src_dir,
+        object_dir => $object_dir,
       }
     );
   }
@@ -200,9 +198,9 @@ sub compile_spvm_csources {
   # Build directory
   my $build_dir = $self->{build_dir};
   
-  # SPVM dir
-  my $build_spvm_dir = "$build_dir/spvm";
-  mkpath $build_spvm_dir;
+  # Object dir
+  my $object_dir = "$build_dir/work/exe/target/object";
+  mkpath $object_dir;
   
   # Compile source files
   my $quiet = $self->{quiet};
@@ -210,7 +208,7 @@ sub compile_spvm_csources {
   my $object_files = [];
   for my $src_file (@$src_files) {
     # Object file
-    my $object_file = "$build_spvm_dir/" . basename($src_file);
+    my $object_file = "$object_dir/" . basename($src_file);
     $object_file =~ s/\.c$//;
     $object_file .= '.o';
     
@@ -227,7 +225,11 @@ sub create_main_csource {
   my ($self, $package_name) = @_;
   
   my $build_dir = $self->{build_dir};
-  my $main_csource_file = "$build_dir/my_main.c";
+  
+  my $src_dir = "$build_dir/work/exe/target/src";
+  mkpath $src_dir;
+  
+  my $main_csource_file = "$build_dir/work/exe/target/src/my_main.c";
 
   # Create c source file
   my $main_csource = $self->build_main_csource($package_name);
@@ -250,8 +252,8 @@ sub compile_main {
   # Compile source files
   my $quiet = $self->{quiet};
   my $cbuilder = ExtUtils::CBuilder->new(quiet => $quiet, config => $config);
-  my $object_file = "$build_dir/my_main.o";
-  my $src_file = "$build_dir/my_main.c";
+  my $object_file = "$build_dir/work/exe/target/object/my_main.o";
+  my $src_file = "$build_dir/work/exe/target/src/my_main.c";
   
   # Compile source file
   $cbuilder->compile(
@@ -270,7 +272,7 @@ sub link_executable {
   my $build_dir = $self->{build_dir};
   
   my $object_files = [];
-  push @$object_files, glob "$build_dir/spvm/*.o";
+  push @$object_files, glob "$build_dir/work/exe/target/object/*.o";
   
   my $builder = $self->builder;
   
@@ -280,7 +282,7 @@ sub link_executable {
   for my $native_package_name (@$native_package_names) {
     my $category = 'native';
     my $native_object_rel_file = SPVM::Builder::Util::convert_package_name_to_category_rel_file_with_ext($native_package_name, $category, 'o');
-    my $native_object_file = "$build_dir/work/tmp/$native_object_rel_file";
+    my $native_object_file = "$build_dir/work/exe/object/$native_object_rel_file";
     if ($native_package_name eq 'SPVM::CORE') {
       $core_native_object_file = $native_object_file;
     }
@@ -296,13 +298,11 @@ sub link_executable {
   for my $precompile_package_name (@$precompile_package_names) {
     my $category = 'precompile';
     my $precompile_object_rel_file = SPVM::Builder::Util::convert_package_name_to_category_rel_file_with_ext($precompile_package_name, $category, 'o');
-    my $precompile_object_file = "$build_dir/work/tmp/$precompile_object_rel_file";
+    my $precompile_object_file = "$build_dir/work/exe/object/$precompile_object_rel_file";
     push @$precompile_object_files, $precompile_object_file;
   }
   push @$object_files, @$precompile_object_files;
   
-  push @$object_files, glob "$build_dir/my_main.o";
-  
   my $build_config = SPVM::Builder::Util::new_default_build_config();
   
   # CBuilder configs
