@@ -222,11 +222,24 @@ enum {
   SPVM_OPCODE_C_ID_NEGATE_LONG,
   SPVM_OPCODE_C_ID_NEGATE_FLOAT,
   SPVM_OPCODE_C_ID_NEGATE_DOUBLE,
-  SPVM_OPCODE_C_ID_GET_CONSTANT_CHAR,
-  SPVM_OPCODE_C_ID_GET_CONSTANT_INT,
-  SPVM_OPCODE_C_ID_GET_CONSTANT_LONG,
-  SPVM_OPCODE_C_ID_GET_CONSTANT_FLOAT,
-  SPVM_OPCODE_C_ID_GET_CONSTANT_DOUBLE,
+  SPVM_OPCODE_C_ID_INIT_BYTE,
+  SPVM_OPCODE_C_ID_INIT_SHORT,
+  SPVM_OPCODE_C_ID_INIT_INT,
+  SPVM_OPCODE_C_ID_INIT_LONG,
+  SPVM_OPCODE_C_ID_INIT_FLOAT,
+  SPVM_OPCODE_C_ID_INIT_DOUBLE,
+  SPVM_OPCODE_C_ID_INIT_UNDEF,
+  SPVM_OPCODE_C_ID_INIT_VALUE_BYTE,
+  SPVM_OPCODE_C_ID_INIT_VALUE_SHORT,
+  SPVM_OPCODE_C_ID_INIT_VALUE_INT,
+  SPVM_OPCODE_C_ID_INIT_VALUE_LONG,
+  SPVM_OPCODE_C_ID_INIT_VALUE_FLOAT,
+  SPVM_OPCODE_C_ID_INIT_VALUE_DOUBLE,
+  SPVM_OPCODE_C_ID_MOVE_CONSTANT_BYTE,
+  SPVM_OPCODE_C_ID_MOVE_CONSTANT_INT,
+  SPVM_OPCODE_C_ID_MOVE_CONSTANT_LONG,
+  SPVM_OPCODE_C_ID_MOVE_CONSTANT_FLOAT,
+  SPVM_OPCODE_C_ID_MOVE_CONSTANT_DOUBLE,
   SPVM_OPCODE_C_ID_MOVE_BYTE,
   SPVM_OPCODE_C_ID_MOVE_SHORT,
   SPVM_OPCODE_C_ID_MOVE_INT,
@@ -234,7 +247,6 @@ enum {
   SPVM_OPCODE_C_ID_MOVE_FLOAT,
   SPVM_OPCODE_C_ID_MOVE_DOUBLE,
   SPVM_OPCODE_C_ID_MOVE_OBJECT,
-  SPVM_OPCODE_C_ID_MOVE_UNDEF,
   SPVM_OPCODE_C_ID_MOVE_REF,
   SPVM_OPCODE_C_ID_CONVERT_BYTE_TO_SHORT,
   SPVM_OPCODE_C_ID_CONVERT_BYTE_TO_INT,
@@ -454,6 +466,7 @@ enum {
   SPVM_OPCODE_C_ID_WEAKEN_FIELD,
   SPVM_OPCODE_C_ID_UNWEAKEN_FIELD,
   SPVM_OPCODE_C_ID_ISWEAK_FIELD,
+  SPVM_OPCODE_C_ID_REFCNT,
   SPVM_OPCODE_C_ID_END_SUB,
 };
 
