@@ -1,7 +1,7 @@
 #include "spvm_native.h"
 #include <stdio.h>
 
-int32_t SPVM_NATIVE_SPVM__FileHandle__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__SPVM__FileHandle__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
 
   // File handle
   void* ofh = stack[0].oval;
